@@ -43,7 +43,7 @@ void read_config(void);
 void read_config_cgi(void);
 void print_entry(time_t, char *, time_t, char *, int, int);
 void print_line(void);
-void scan_args(int, char*[]);
-void print_usage(void);
-void print_help(void);
+void scan_args(int, char *[]);
+void print_usage(char *[]);
+void print_help(char *[]);
 void print_version(void);
