@@ -39,7 +39,7 @@ time_t get_prev(void);
 void read_config(void);
 void handler(int);
 void scan_args(int, char *[]);
-void print_usage(void);
-void print_help(void);
+void print_usage(char *[]);
+void print_help(char *[]);
 void print_version(void);
 void mail(Milestone *, int);
